==> knative-model-6.4.1-sources.jar: io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaTLSSpecFluentImpl.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class KafkaTLSSpecFluentImpl<A extends KafkaTLSSpecFluent<A>> extends BaseFluent<A> implements KafkaTLSSpecFluent<A>{
  public KafkaTLSSpecFluentImpl() {
  }
  public KafkaTLSSpecFluentImpl(KafkaTLSSpec instance) {
    this.withCaCert(instance.getCaCert()); 
    this.withCert(instance.getCert()); 
    this.withEnable(instance.getEnable()); 
    this.withKey(instance.getKey()); 
  }
  private SecretValueFromSourceBuilder caCert;
  private SecretValueFromSourceBuilder cert;
  private Boolean enable;
  private SecretValueFromSourceBuilder key;
  
  /**
   * This method has been deprecated, please use method buildCaCert instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretValueFromSource getCaCert() {
    return this.caCert!=null ?this.caCert.build():null;
  }
  public SecretValueFromSource buildCaCert() {
    return this.caCert!=null ?this.caCert.build():null;
  }
  public A withCaCert(SecretValueFromSource caCert) {
    _visitables.get("caCert").remove(this.caCert);
    if (caCert!=null){ this.caCert= new SecretValueFromSourceBuilder(caCert); _visitables.get("caCert").add(this.caCert);} else { this.caCert = null; _visitables.get("caCert").remove(this.caCert); } return (A) this;
  }
  public Boolean hasCaCert() {
    return this.caCert != null;
  }
  public KafkaTLSSpecFluent.CaCertNested<A> withNewCaCert() {
    return new KafkaTLSSpecFluentImpl.CaCertNestedImpl();
  }
  public KafkaTLSSpecFluent.CaCertNested<A> withNewCaCertLike(SecretValueFromSource item) {
    return new KafkaTLSSpecFluentImpl.CaCertNestedImpl(item);
  }
  public KafkaTLSSpecFluent.CaCertNested<A> editCaCert() {
    return withNewCaCertLike(getCaCert());
  }
  public KafkaTLSSpecFluent.CaCertNested<A> editOrNewCaCert() {
    return withNewCaCertLike(getCaCert() != null ? getCaCert(): new SecretValueFromSourceBuilder().build());
  }
  public KafkaTLSSpecFluent.CaCertNested<A> editOrNewCaCertLike(SecretValueFromSource item) {
    return withNewCaCertLike(getCaCert() != null ? getCaCert(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildCert instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretValueFromSource getCert() {
    return this.cert!=null ?this.cert.build():null;
  }
  public SecretValueFromSource buildCert() {
    return this.cert!=null ?this.cert.build():null;
  }
  public A withCert(SecretValueFromSource cert) {
    _visitables.get("cert").remove(this.cert);
    if (cert!=null){ this.cert= new SecretValueFromSourceBuilder(cert); _visitables.get("cert").add(this.cert);} else { this.cert = null; _visitables.get("cert").remove(this.cert); } return (A) this;
  }
  public Boolean hasCert() {
    return this.cert != null;
  }
  public KafkaTLSSpecFluent.CertNested<A> withNewCert() {
    return new KafkaTLSSpecFluentImpl.CertNestedImpl();
  }
  public KafkaTLSSpecFluent.CertNested<A> withNewCertLike(SecretValueFromSource item) {
    return new KafkaTLSSpecFluentImpl.CertNestedImpl(item);
  }
  public KafkaTLSSpecFluent.CertNested<A> editCert() {
    return withNewCertLike(getCert());
  }
  public KafkaTLSSpecFluent.CertNested<A> editOrNewCert() {
    return withNewCertLike(getCert() != null ? getCert(): new SecretValueFromSourceBuilder().build());
  }
  public KafkaTLSSpecFluent.CertNested<A> editOrNewCertLike(SecretValueFromSource item) {
    return withNewCertLike(getCert() != null ? getCert(): item);
  }
  public Boolean getEnable() {
    return this.enable;
  }
  public A withEnable(Boolean enable) {
    this.enable=enable; return (A) this;
  }
  public Boolean hasEnable() {
    return this.enable != null;
  }
  
  /**
   * This method has been deprecated, please use method buildKey instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretValueFromSource getKey() {
    return this.key!=null ?this.key.build():null;
  }
  public SecretValueFromSource buildKey() {
    return this.key!=null ?this.key.build():null;
  }
  public A withKey(SecretValueFromSource key) {
    _visitables.get("key").remove(this.key);
    if (key!=null){ this.key= new SecretValueFromSourceBuilder(key); _visitables.get("key").add(this.key);} else { this.key = null; _visitables.get("key").remove(this.key); } return (A) this;
  }
  public Boolean hasKey() {
    return this.key != null;
  }
  public KafkaTLSSpecFluent.KeyNested<A> withNewKey() {
    return new KafkaTLSSpecFluentImpl.KeyNestedImpl();
  }
  public KafkaTLSSpecFluent.KeyNested<A> withNewKeyLike(SecretValueFromSource item) {
    return new KafkaTLSSpecFluentImpl.KeyNestedImpl(item);
  }
  public KafkaTLSSpecFluent.KeyNested<A> editKey() {
    return withNewKeyLike(getKey());
  }
  public KafkaTLSSpecFluent.KeyNested<A> editOrNewKey() {
    return withNewKeyLike(getKey() != null ? getKey(): new SecretValueFromSourceBuilder().build());
  }
  public KafkaTLSSpecFluent.KeyNested<A> editOrNewKeyLike(SecretValueFromSource item) {
    return withNewKeyLike(getKey() != null ? getKey(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    KafkaTLSSpecFluentImpl that = (KafkaTLSSpecFluentImpl) o;
    if (caCert != null ? !caCert.equals(that.caCert) :that.caCert != null) return false;
    if (cert != null ? !cert.equals(that.cert) :that.cert != null) return false;
    if (enable != null ? !enable.equals(that.enable) :that.enable != null) return false;
    if (key != null ? !key.equals(that.key) :that.key != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(caCert,  cert,  enable,  key,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (caCert != null) { sb.append("caCert:"); sb.append(caCert + ","); }
    if (cert != null) { sb.append("cert:"); sb.append(cert + ","); }
    if (enable != null) { sb.append("enable:"); sb.append(enable + ","); }
    if (key != null) { sb.append("key:"); sb.append(key); }
    sb.append("}");
    return sb.toString();
  }
  public A withEnable() {
    return withEnable(true);
  }
  class CaCertNestedImpl<N> extends SecretValueFromSourceFluentImpl<KafkaTLSSpecFluent.CaCertNested<N>> implements KafkaTLSSpecFluent.CaCertNested<N>,Nested<N>{
    CaCertNestedImpl(SecretValueFromSource item) {
      this.builder = new SecretValueFromSourceBuilder(this, item);
    }
    CaCertNestedImpl() {
      this.builder = new SecretValueFromSourceBuilder(this);
    }
    SecretValueFromSourceBuilder builder;
    public N and() {
      return (N) KafkaTLSSpecFluentImpl.this.withCaCert(builder.build());
    }
    public N endCaCert() {
      return and();
    }
    
  }
  class CertNestedImpl<N> extends SecretValueFromSourceFluentImpl<KafkaTLSSpecFluent.CertNested<N>> implements KafkaTLSSpecFluent.CertNested<N>,Nested<N>{
    CertNestedImpl(SecretValueFromSource item) {
      this.builder = new SecretValueFromSourceBuilder(this, item);
    }
    CertNestedImpl() {
      this.builder = new SecretValueFromSourceBuilder(this);
    }
    SecretValueFromSourceBuilder builder;
    public N and() {
      return (N) KafkaTLSSpecFluentImpl.this.withCert(builder.build());
    }
    public N endCert() {
      return and();
    }
    
  }
  class KeyNestedImpl<N> extends SecretValueFromSourceFluentImpl<KafkaTLSSpecFluent.KeyNested<N>> implements KafkaTLSSpecFluent.KeyNested<N>,Nested<N>{
    KeyNestedImpl(SecretValueFromSource item) {
      this.builder = new SecretValueFromSourceBuilder(this, item);
    }
    KeyNestedImpl() {
      this.builder = new SecretValueFromSourceBuilder(this);
    }
    SecretValueFromSourceBuilder builder;
    public N and() {
      return (N) KafkaTLSSpecFluentImpl.this.withKey(builder.build());
    }
    public N endKey() {
      return and();
    }
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaTLSSpecFluentImpl.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class KafkaTLSSpecFluentImpl<A extends KafkaTLSSpecFluent<A>> extends BaseFluent<A> implements KafkaTLSSpecFluent<A>{
  public KafkaTLSSpecFluentImpl() {
  }
  public KafkaTLSSpecFluentImpl(KafkaTLSSpec instance) {
    if (instance != null) {
      this.withCaCert(instance.getCaCert());
      this.withCert(instance.getCert());
      this.withEnable(instance.getEnable());
      this.withKey(instance.getKey());
    }
  }
  private SecretValueFromSourceBuilder caCert;
  private SecretValueFromSourceBuilder cert;
  private Boolean enable;
  private SecretValueFromSourceBuilder key;
  
  /**
   * This method has been deprecated, please use method buildCaCert instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretValueFromSource getCaCert() {
    return this.caCert!=null ?this.caCert.build():null;
  }
  public SecretValueFromSource buildCaCert() {
    return this.caCert!=null ?this.caCert.build():null;
  }
  public A withCaCert(SecretValueFromSource caCert) {
    _visitables.get("caCert").remove(this.caCert);
    if (caCert!=null){ this.caCert= new SecretValueFromSourceBuilder(caCert); _visitables.get("caCert").add(this.caCert);} else { this.caCert = null; _visitables.get("caCert").remove(this.caCert); } return (A) this;
  }
  public Boolean hasCaCert() {
    return this.caCert != null;
  }
  public KafkaTLSSpecFluentImpl.CaCertNested<A> withNewCaCert() {
    return new KafkaTLSSpecFluentImpl.CaCertNestedImpl();
  }
  public KafkaTLSSpecFluentImpl.CaCertNested<A> withNewCaCertLike(SecretValueFromSource item) {
    return new KafkaTLSSpecFluentImpl.CaCertNestedImpl(item);
  }
  public KafkaTLSSpecFluentImpl.CaCertNested<A> editCaCert() {
    return withNewCaCertLike(getCaCert());
  }
  public KafkaTLSSpecFluentImpl.CaCertNested<A> editOrNewCaCert() {
    return withNewCaCertLike(getCaCert() != null ? getCaCert(): new SecretValueFromSourceBuilder().build());
  }
  public KafkaTLSSpecFluentImpl.CaCertNested<A> editOrNewCaCertLike(SecretValueFromSource item) {
    return withNewCaCertLike(getCaCert() != null ? getCaCert(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildCert instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretValueFromSource getCert() {
    return this.cert!=null ?this.cert.build():null;
  }
  public SecretValueFromSource buildCert() {
    return this.cert!=null ?this.cert.build():null;
  }
  public A withCert(SecretValueFromSource cert) {
    _visitables.get("cert").remove(this.cert);
    if (cert!=null){ this.cert= new SecretValueFromSourceBuilder(cert); _visitables.get("cert").add(this.cert);} else { this.cert = null; _visitables.get("cert").remove(this.cert); } return (A) this;
  }
  public Boolean hasCert() {
    return this.cert != null;
  }
  public KafkaTLSSpecFluentImpl.CertNested<A> withNewCert() {
    return new KafkaTLSSpecFluentImpl.CertNestedImpl();
  }
  public KafkaTLSSpecFluentImpl.CertNested<A> withNewCertLike(SecretValueFromSource item) {
    return new KafkaTLSSpecFluentImpl.CertNestedImpl(item);
  }
  public KafkaTLSSpecFluentImpl.CertNested<A> editCert() {
    return withNewCertLike(getCert());
  }
  public KafkaTLSSpecFluentImpl.CertNested<A> editOrNewCert() {
    return withNewCertLike(getCert() != null ? getCert(): new SecretValueFromSourceBuilder().build());
  }
  public KafkaTLSSpecFluentImpl.CertNested<A> editOrNewCertLike(SecretValueFromSource item) {
    return withNewCertLike(getCert() != null ? getCert(): item);
  }
  public Boolean getEnable() {
    return this.enable;
  }
  public A withEnable(Boolean enable) {
    this.enable=enable; return (A) this;
  }
  public Boolean hasEnable() {
    return this.enable != null;
  }
  
  /**
   * This method has been deprecated, please use method buildKey instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretValueFromSource getKey() {
    return this.key!=null ?this.key.build():null;
  }
  public SecretValueFromSource buildKey() {
    return this.key!=null ?this.key.build():null;
  }
  public A withKey(SecretValueFromSource key) {
    _visitables.get("key").remove(this.key);
    if (key!=null){ this.key= new SecretValueFromSourceBuilder(key); _visitables.get("key").add(this.key);} else { this.key = null; _visitables.get("key").remove(this.key); } return (A) this;
  }
  public Boolean hasKey() {
    return this.key != null;
  }
  public KafkaTLSSpecFluentImpl.KeyNested<A> withNewKey() {
    return new KafkaTLSSpecFluentImpl.KeyNestedImpl();
  }
  public KafkaTLSSpecFluentImpl.KeyNested<A> withNewKeyLike(SecretValueFromSource item) {
    return new KafkaTLSSpecFluentImpl.KeyNestedImpl(item);
  }
  public KafkaTLSSpecFluentImpl.KeyNested<A> editKey() {
    return withNewKeyLike(getKey());
  }
  public KafkaTLSSpecFluentImpl.KeyNested<A> editOrNewKey() {
    return withNewKeyLike(getKey() != null ? getKey(): new SecretValueFromSourceBuilder().build());
  }
  public KafkaTLSSpecFluentImpl.KeyNested<A> editOrNewKeyLike(SecretValueFromSource item) {
    return withNewKeyLike(getKey() != null ? getKey(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    KafkaTLSSpecFluentImpl that = (KafkaTLSSpecFluentImpl) o;
    if (!java.util.Objects.equals(caCert, that.caCert)) return false;

    if (!java.util.Objects.equals(cert, that.cert)) return false;

    if (!java.util.Objects.equals(enable, that.enable)) return false;

    if (!java.util.Objects.equals(key, that.key)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(caCert,  cert,  enable,  key,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (caCert != null) { sb.append("caCert:"); sb.append(caCert + ","); }
    if (cert != null) { sb.append("cert:"); sb.append(cert + ","); }
    if (enable != null) { sb.append("enable:"); sb.append(enable + ","); }
    if (key != null) { sb.append("key:"); sb.append(key); }
    sb.append("}");
    return sb.toString();
  }
  public A withEnable() {
    return withEnable(true);
  }
  class CaCertNestedImpl<N> extends SecretValueFromSourceFluentImpl<KafkaTLSSpecFluentImpl.CaCertNested<N>> implements KafkaTLSSpecFluentImpl.CaCertNested<N>,Nested<N>{
    CaCertNestedImpl(SecretValueFromSource item) {
      this.builder = new SecretValueFromSourceBuilder(this, item);
    }
    CaCertNestedImpl() {
      this.builder = new SecretValueFromSourceBuilder(this);
    }
    SecretValueFromSourceBuilder builder;
    public N and() {
      return (N) KafkaTLSSpecFluentImpl.this.withCaCert(builder.build());
    }
    public N endCaCert() {
      return and();
    }
    
  }
  class CertNestedImpl<N> extends SecretValueFromSourceFluentImpl<KafkaTLSSpecFluentImpl.CertNested<N>> implements KafkaTLSSpecFluentImpl.CertNested<N>,Nested<N>{
    CertNestedImpl(SecretValueFromSource item) {
      this.builder = new SecretValueFromSourceBuilder(this, item);
    }
    CertNestedImpl() {
      this.builder = new SecretValueFromSourceBuilder(this);
    }
    SecretValueFromSourceBuilder builder;
    public N and() {
      return (N) KafkaTLSSpecFluentImpl.this.withCert(builder.build());
    }
    public N endCert() {
      return and();
    }
    
  }
  class KeyNestedImpl<N> extends SecretValueFromSourceFluentImpl<KafkaTLSSpecFluentImpl.KeyNested<N>> implements KafkaTLSSpecFluentImpl.KeyNested<N>,Nested<N>{
    KeyNestedImpl(SecretValueFromSource item) {
      this.builder = new SecretValueFromSourceBuilder(this, item);
    }
    KeyNestedImpl() {
      this.builder = new SecretValueFromSourceBuilder(this);
    }
    SecretValueFromSourceBuilder builder;
    public N and() {
      return (N) KafkaTLSSpecFluentImpl.this.withKey(builder.build());
    }
    public N endKey() {
      return and();
    }
    
  }
  
}
